@@ -6,7 +6,7 @@ class Instruction(SimpleNamespace):
         if in_dict is not None:
             super().__init__(**in_dict)
         else:
-            super().__init__(**{a:b for a,b in zip(dis.Instruction._fields+('jump_to', 'was_there'), instruction + (None, True))})
+            super().__init__(**{a:b for a,b in zip(dis.Instruction._fields+('jump_to', 'was_there', 'extra_extended_args'), instruction + (None, True, 0))})
 
     def is_jumper(self):
         return self.is_abs_jumper() or self.is_rel_jumper()
@@ -22,12 +22,13 @@ class Instruction(SimpleNamespace):
         return Instruction(None, in_dict={
             'opcode':144, 'opname':'EXTENDED_ARGS', 'arg':value,
             'argval':value, 'argrepr':value, 'offset':None,
-            'starts_line':None, 'is_jump_target':False, 'was_there': False
+            'starts_line':None, 'is_jump_target':False, 'was_there': False,
+            'extra_extended_args': 0,
         })
 
     def calculate_offset(self, instructions):
         # Return the offset (rel or abs) to self.jump_to in instructions
-        target_loc = 2 * instructions.index(self.jump_to)
+        target_loc = 2 * instructions.index(self.jump_to) - 2 * self.jump_to.extra_extended_args
 
         if self.is_abs_jumper():
             return target_loc
